@@ -80,6 +80,9 @@ CANT_MIX_MAPPING_IN_FORMATS = "Can't mix tuple/mapping (dictionary) formats in s
 
 INTEGER_DIVISION = "Using integer division (%s / %s) may return integer or float"
 USING_TUPLE_ACCESS_TO_LIST = "Using a tuple instead of slice as list accessor for (%s)"
+BOOL_COMPARE = "Comparisons with %s are not necessary and may not work as expected"
+SHOULDNT_ASSIGN_BUILTIN = "Should not assign to %s, it is (or will be) a builtin"
+SHOULDNT_ASSIGN_NAME = "Should not assign to %s, it is similar to builtin %s"
 
 STMT_WITH_NO_EFFECT = "Operator (%s) doesn't exist, statement has no effect"
 POSSIBLE_STMT_WITH_NO_EFFECT = "Statement appears to have no effect"
@@ -90,18 +93,29 @@ LOCAL_DELETED = "(%s) cannot be used after being deleted on line %d"
 LOCAL_ALREADY_DELETED = "Local variable (%s) has already been deleted on line %d"
 VAR_DELETED_BEFORE_SET = "Variable (%s) deleted before being set"
 
+CATCH_BAD_EXCEPTION = "Catching a non-Exception object (%s)"
+CATCH_STR_EXCEPTION = "Catching string exceptions are deprecated (%s)"
+RAISE_BAD_EXCEPTION = "Raising an exception on a non-Exception object (%s)"
+RAISE_STR_EXCEPTION = "Raising string exceptions are deprecated (%s)"
 SET_EXCEPT_TO_BUILTIN = "Setting exception to builtin (%s), consider () around exceptions"
 USING_KEYWORD = "Using identifier (%s) which will become a keyword in version %s"
 MODIFYING_DEFAULT_ARG = "Modifying parameter (%s) with a default value may have unexpected consequences"
 USING_SELF_IN_REPR = "Using `self` in __repr__ method"
 USING_NONE_RETURN_VALUE = "Using the return value from (%s) which is always None"
 WRONG_UNPACK_SIZE = "Unpacking %d values into %d variables"
+WRONG_UNPACK_FUNCTION = "Unpacking function (%s) which returns %d values into %d variables"
 UNPACK_NON_SEQUENCE = "Unpacking a non-sequence (%s) of type %s"
 
+USING_COERCE_IN_NEW_CLASS = "Using __coerce__ in new-style class (%s) will not work for binary operations"
 USING_PROPERTIES_IN_CLASSIC_CLASS = "Using property (%s) in classic class %s may not work"
-USING_SLOTS_IN_CLASSIC_CLASS = "Using __slots__ in classic class %s is not used by Python"
+USING_SLOTS_IN_CLASSIC_CLASS = "Using __slots__ in classic class %s has no effect, consider deriving from object"
 EMPTY_SLOTS = "__slots__ are empty in %s"
 
 USES_EXEC = "Using the exec statement"
 USES_GLOBAL_EXEC = "Using the exec statement in global namespace"
 USES_INPUT = "Using input() is a security problem, consider using raw_input()"
+
+USING_DEPRECATED_MODULE = "%s module is deprecated"
+USING_DEPRECATED_ATTR = "%s is deprecated"
+USING_INSECURE_FUNC = "%s() is a security problem"
+USE_INSTEAD = ", consider using %s"
