@@ -2,8 +2,10 @@
 
 TESTS="test_input/test[1-9]*.py"
 # comment out to use python from path
-# PYTHON="$HOME/local/bin/python2.2"
+PYTHON="python"
+# PYTHON="$HOME/build/python/dist/src/python"
 # PYTHON="/usr/bin/python"
+# PYTHON="$PYTHON -tt coverage.py -x"
 
 if [ $# -gt 0 ]; then
     TESTS=""
@@ -12,31 +14,34 @@ if [ $# -gt 0 ]; then
     done
 fi
 
-if [ -z $TMP ]; then
+if [ -z "$TMP" ]; then
     TMP=/tmp
 fi
 
 error=0
 
+VERSION=`$PYTHON -c "import sys ; print '%d.%d' % sys.version_info[0:2]"`
 FAILED=""
 NO_EXPECTED_RESULTS=""
 for test_file in $TESTS ; do
     echo "Testing $test_file ..."
     test_name=`basename $test_file .py`
     expected=test_expected/$test_name
-    if [ ! -e $expected ]; then
+    if [ -e ${expected}-$VERSION ]; then
+        expected=${expected}-$VERSION
+    elif [ ! -e $expected ]; then
         echo "  WARNING:  $expected expected results does not exist"
-	NO_EXPECTED_RESULTS="$NO_EXPECTED_RESULTS $test_name"
-	continue
+        NO_EXPECTED_RESULTS="$NO_EXPECTED_RESULTS $test_name"
+        continue
     fi
 
     test_path=$TMP/$test_name
-    $PYTHON ./pychecker/checker.py --moduledoc --classdoc --no-argsused $test_file > $test_path 2>&1
+    $PYTHON -tt ./pychecker/checker.py --moduledoc --classdoc --no-argsused $test_file > $test_path 2>&1
     diff $test_path $expected
     if [ $? -ne 0 ]; then
-    	error=`expr $error + 1`
-	echo "  $test_name FAILED"
-	FAILED="$FAILED $test_name"
+        error=`expr $error + 1`
+        echo "  $test_name FAILED"
+        FAILED="$FAILED $test_name"
     fi
     rm -f $test_path
 done
